## cdist-type__user_groups(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__user_groups - manage user groups

## 2. DESCRIPTION

Adds or removes a user from one or more groups.

## 3. REQUIRED PARAMETERS

group
  the group to which this user should be added or removed. Can be specified multiple times.

## 4. OPTIONAL PARAMETERS

user
  the name of the user. Defaults to object_id
state
  absent or present. Defaults to present.

## 5. EXAMPLES

    __user_groups nginx --group webuser1 --group webuser2

    # remove user nginx from groups webuser2
    __user_groups nginx-webuser2 --user nginx \
       --group webuser2 --state absent

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2012 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).